get_wlx_evaluations

Function get_wlx_evaluations 

pub fn get_wlx_evaluations<F: Field>(
    claim_vecs: &[Vec<F>],
    claimed_vals: &[F],
    claim_mles: Vec<DenseMle<F>>,
    num_claims: usize,
    num_idx: usize,
) -> Result<Vec<F>>
Returns a vector of evaluations of this layer’s MLE on a sequence of points computed by interpolating a polynomial that passes through the points of claims_vecs.