prover_aggregate_claims

Function prover_aggregate_claims 

pub fn prover_aggregate_claims<F: Field>(
    claims: &[Claim<F>],
    output_mles_from_layer: Vec<DenseMle<F>>,
    transcript_writer: &mut impl ProverTranscript<F>,
) -> Result<RawClaim<F>>
Performs claim aggregation on the prover side and, if successful, returns a single, raw aggregated claim.

Parameters

  • claims: a slice of claims, all on the same layer (same to_layer_id), to be aggregated into one.
  • layer: the GKR layer that this claim group is making claims on; the layer whose ID matches the to_layer_id field of all elements in claims.
  • output_mles_from_layer: the compiled bookkeeping tables that result from this layer, in order to aggregate into the layerwise bookkeeping table.
  • transcript_writer: is used to post the interpolation polynomial evaluations and generate challenges.