verifier_aggregate_claims

Function verifier_aggregate_claims 

pub fn verifier_aggregate_claims<F: Field>(
    claims: &[Claim<F>],
    transcript_reader: &mut impl VerifierTranscript<F>,
) -> Result<RawClaim<F>>
Performs claim aggregation on the verifier side.

  • claims: a group of claims, all on the same layer (same to_layer_id), to be aggregated into one.
  • transcript_reader: is used to retrieve the wlx evaluations and generate challenges.

Returns

If successful, returns a single aggregated claim.