pub fn get_num_wlx_evaluations<F: Field>(
claim_vecs: &[Vec<F>],
) -> (usize, Option<Vec<usize>>, Vec<usize>)Expand description
Returns an upper bound on the number of evaluations needed to represent the
polynomial P(x) = W(l(x)) where W : F^n -> F is a multilinear polynomial
on n variables and l : F -> F^n is such that:
l(0) = claim_vecs[0],l(1) = claim_vecs[1],- …,
l(m-1) = claim_vecs[m-1].
It is guaranteed that the returned value is at least num_claims = claim_vecs.len().
Panics
if claim_vecs is empty.